package com.mapmyindia.sdk.flutter.place

import android.graphics.BitmapFactory
import android.graphics.Color
import com.mapmyindia.sdk.geojson.Point
import com.mapmyindia.sdk.maps.camera.CameraPosition
import com.mapmyindia.sdk.maps.geometry.LatLng
import com.mapmyindia.sdk.maps.geometry.LatLngBounds
import com.mapmyindia.sdk.plugins.places.autocomplete.model.PlaceOptions
import com.mapmyindia.sdk.plugins.places.placepicker.model.PlacePickerOptions

/**
 ** Created by Saksham on 30-11-2020.
 **/
object Utils {

    fun getPlaceOptions(params: Map<String, Any?>): PlaceOptions {
        val builder: PlaceOptions.Builder = PlaceOptions.builder()
        if (params.containsKey("enableTextSearch")) {
            builder.enableTextSearch(params["enableTextSearch"] as Boolean?)
        }
        if (params.containsKey("filter")) {
            builder.filter(params["filter"] as String?)
        }
        if (params.containsKey("hint")) {
            builder.hint(params["hint"] as String?)
        }
        if (params.containsKey("historyCount")) {
            builder.historyCount(params["historyCount"] as Int?)
        }
        if (params.containsKey("limit")) {
            builder.limit(params["limit"] as Int)
        }
        if (params.containsKey("pod")) {
            builder.pod(params["pod"] as String?)
        }
        if (params.containsKey("saveHistory")) {
            builder.saveHistory(params["saveHistory"] as Boolean?)
        }
        if (params.containsKey("backgroundColor")) {
            val color = params["backgroundColor"] as String
            builder.backgroundColor(Color.parseColor(color))
        }
        if (params.containsKey("statusbarColor")) {
            val color = params["statusbarColor"] as String
            builder.statusBarColor(Color.parseColor(color))
        }
        if (params.containsKey("toolbarColor")) {
            val color = params["toolbarColor"] as String
            builder.toolbarColor(Color.parseColor(color))
        }
        if (params.containsKey("toolbarTintColor")) {
            val color = params["toolbarTintColor"] as String
            builder.toolbarTintColor(Color.parseColor(color))
        }
        if (params.containsKey("tokenizeAddress")) {
            builder.tokenizeAddress(params["tokenizeAddress"] as Boolean?)
        }
        if (params.containsKey("userAddedLocationEnable")) {
            builder.userAddedLocationEnable(params["userAddedLocationEnable"] as Boolean?)
        }
        if (params.containsKey("zoom")) {
            builder.zoom(params["zoom"] as Double?)
        }
        if (params.containsKey("location")) {
            val locations: List<Double> = params["location"] as List<Double>
            builder.location(Point.fromLngLat(locations[1], locations[0]))
        }
        if (params.containsKey("attributionHorizontalAlignment")) {
            when (params["attributionHorizontalAlignment"] as Int) {
                1 -> {
                    builder.attributionVerticalAlignment(PlaceOptions.GRAVITY_LEFT)
                }
                2 -> {
                    builder.attributionVerticalAlignment(PlaceOptions.GRAVITY_CENTER)
                }
                3 -> {
                    builder.attributionVerticalAlignment(PlaceOptions.GRAVITY_RIGHT)
                }
            }
        }

        if (params.containsKey("attributionVerticalAlignment")) {
            val attributionVerticalAlignment = params["attributionVerticalAlignment"] as Int
            if (attributionVerticalAlignment == 4) {
                builder.attributionHorizontalAlignment(PlaceOptions.GRAVITY_TOP)
            } else if (attributionVerticalAlignment == 5) {
                builder.attributionHorizontalAlignment(PlaceOptions.GRAVITY_BOTTOM)
            }

        }
        if (params.containsKey("logoSize")) {
            when (params["logoSize"] as Int) {
                6 -> {
                    builder.logoSize(PlaceOptions.SIZE_SMALL)
                }
                7 -> {
                    builder.logoSize(PlaceOptions.SIZE_MEDIUM)
                }
                8 -> {
                    builder.logoSize(PlaceOptions.SIZE_LARGE)
                }
            }

        }
        if(params.containsKey("minCharactersForSearch")) {
            builder.minCharactersForSearch(params["minCharactersForSearch"] as Int)
        }
        if(params.containsKey("hyperLocal")) {
            builder.hyperLocal(params["hyperLocal"] as Boolean)
        }
        if(params.containsKey("bridge")) {
            builder.bridge(params["bridge"] as Boolean)
        }
        return builder.build()

    }

    fun getPickerOption(params: Map<String, Any?>): PlacePickerOptions {
        val builder: PlacePickerOptions.Builder = PlacePickerOptions.builder();
        if (params.containsKey("includeDeviceLocationButton")) {
            builder.includeDeviceLocationButton(params["includeDeviceLocationButton"] as Boolean)
        }
        if (params.containsKey("includeSearch")) {
            builder.includeSearch(params["includeSearch"] as Boolean)
        }
        if (params.containsKey("mapMaxZoom")) {
            builder.mapMaxZoom(params["mapMaxZoom"] as Double)
        }
        if (params.containsKey("mapMinZoom")) {
            builder.mapMinZoom(params["mapMinZoom"] as Double)
        }
        if (params.containsKey("searchPlaceOption")) {
            builder.searchPlaceOption(getPlaceOptions(params["searchPlaceOption"] as Map<String, Any?>))
        }
        if (params.containsKey("toolbarColor")) {
            val color = params["toolbarColor"] as String
            builder.toolbarColor(Color.parseColor(color))
        }
        if (params.containsKey("marker")) {
            val marker: Map<String, Any?> = params["marker"] as Map<String, Any?>
            val bitmap = BitmapFactory.decodeByteArray(
                marker["image"] as ByteArray?,
                0,
                marker["length"] as Int
            )
            builder.markerBitmap(bitmap)
        }
        if (params.containsKey("statingCameraPosition")) {
            builder.statingCameraPosition(toCameraPosition(params["statingCameraPosition"] as Map<String, Any>))
        }
        if (params.containsKey("startingBounds")) {
            builder.startingBounds(toLatLngBounds(params["startingBounds"] as List<List<Double>>))
        }
        if (params.containsKey("toolbarTintColor")) {
            val color = params["toolbarTintColor"] as String
            builder.toolbarTintColor(Color.parseColor(color))
        }
        if (params.containsKey("addressTextColor")) {
            val color = params["addressTextColor"] as String
            builder.addressTextColor(Color.parseColor(color))
        }
        if (params.containsKey("placeNameLabelTextColor")) {
            val color = params["placeNameLabelTextColor"] as String
            builder.placeNameTextColor(Color.parseColor(color))
        }
        if (params.containsKey("pickerButtonTitleColor")) {
            val color = params["pickerButtonTitleColor"] as String
            builder.pickerButtonTextColor(Color.parseColor(color))
        }
        if (params.containsKey("pickerButtonBackgroundColor")) {
            val color = params["pickerButtonBackgroundColor"] as String
            builder.pickerButtonBackgroundColor(Color.parseColor(color))
        }
        if (params.containsKey("pickerButtonTitle")) {
            builder.pickerButtonText(params["pickerButtonTitle"] as String)
        }
        if (params.containsKey("showMarkerShadow")) {
            builder.showMarkerShadow(params["showMarkerShadow"] as Boolean)
        }

        return builder.build()
    }

    private fun toCameraPosition(params: Map<String, Any>): CameraPosition {
        val builder = CameraPosition.Builder()
        builder.bearing(params["bearing"] as Double)
        builder.tilt(params["tilt"] as Double)
        builder.zoom(params["zoom"] as Double)
        val locations: List<Double> = params["target"] as List<Double>
        builder.target(LatLng(locations[0], locations[1]))
        return builder.build()
    }

    private fun toLatLngBounds(params: List<List<Double>>): LatLngBounds {
        val latLngList: MutableList<LatLng> = ArrayList()
        latLngList.add(LatLng(params[0][0], params[0][1]))
        latLngList.add(LatLng(params[1][0], params[1][1]))

        val builder = LatLngBounds.Builder()
        builder.includes(latLngList)
        return builder.build()
    }
}