import 'package:flutter/material.dart';
import 'package:flutter/rendering.dart';
import 'package:flutter_colorpicker/flutter_colorpicker.dart';
import 'package:group_radio_button/group_radio_button.dart';
import 'package:mapmyindia_place_flutter_example/pickerSettings.dart';
import 'package:mapmyindia_place_flutter_example/placeSearchSettings.dart';
import 'package:mapmyindia_place_widget/mapmyindia_place_widget.dart';

class PickerSettingsWidget extends StatefulWidget {
  @override
  _PickerSettingsWidgetState createState() => _PickerSettingsWidgetState();
}

class _PickerSettingsWidgetState extends State<PickerSettingsWidget> {
  bool isTokenizeAddress = PickerSettings().tokenizeAddress;
  bool isSaveHistory = PickerSettings().saveHistory;
  bool isIncludeSearch = PickerSettings().includeSearch;
  bool isIncludeDeviceLocationButton = PickerSettings().includeDeviceLocationButton;
  bool isShowMarkerShadow = PickerSettings().showMarkerShadow;

  // create some values
  Color backgroundColor = Color(
      int.parse(PickerSettings().backgroundColor.replaceAll("#", "0xff")));
  Color toolbarColor = Color(int.parse(PickerSettings().toolbarColor.replaceAll("#", "0xff")));
  Color pickerToolbarColor = Color(int.parse(PickerSettings().pickerToolbarColor.replaceAll("#", "0xff")));
  Color addressTextColor = Color(int.parse(PickerSettings().addressTextColor.replaceAll("#", "0xff")));
  Color labelTextColor = Color(int.parse(PickerSettings().placeNameLabelTextColor.replaceAll("#", "0xff")));
  Color infoBottomViewBackground = Color(int.parse(PickerSettings().infoBottomViewBackgroundColor.replaceAll("#", "0xff")));

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
        home: Scaffold(
            appBar: AppBar(
              title: const Text('Place Picker Settings'),
            ),
            body: SingleChildScrollView(
              child: Padding(
                padding: EdgeInsets.all(10),
                child: Column(children: [
                  Row(
                    mainAxisAlignment: MainAxisAlignment.spaceBetween,
                    children: [
                      Text("include Search"),
                      Switch(
                        onChanged: (bool value) {
                          PickerSettings().includeSearch = value;
                          print(value);
                          setState(() {
                            isIncludeSearch = value;
                          });
                        },
                        value: isIncludeSearch,
                        activeColor: Colors.blue,
                        activeTrackColor: Colors.yellow,
                        inactiveThumbColor: Colors.redAccent,
                        inactiveTrackColor: Colors.orange,
                      )
                    ],
                  ),

                  Divider(
                    color: Colors.grey,
                    height: 5,
                  ),
                  Row(
                    mainAxisAlignment: MainAxisAlignment.spaceBetween,
                    children: [
                      Text("include Device Location Button"),
                      Switch(
                        onChanged: (bool value) {
                          PickerSettings().includeDeviceLocationButton = value;
                          print(value);
                          setState(() {
                            isIncludeDeviceLocationButton = value;
                          });
                        },
                        value: isIncludeDeviceLocationButton,
                        activeColor: Colors.blue,
                        activeTrackColor: Colors.yellow,
                        inactiveThumbColor: Colors.redAccent,
                        inactiveTrackColor: Colors.orange,
                      )
                    ],
                  ),

                  Divider(
                    color: Colors.grey,
                    height: 5,
                  ),
                  Row(
                    mainAxisAlignment: MainAxisAlignment.spaceBetween,
                    children: [
                      Text("Show Marker Shadow"),
                      Switch(
                        onChanged: (bool value) {
                          PickerSettings().showMarkerShadow = value;
                          print(value);
                          setState(() {
                            isShowMarkerShadow = value;
                          });
                        },
                        value: isShowMarkerShadow,
                        activeColor: Colors.blue,
                        activeTrackColor: Colors.yellow,
                        inactiveThumbColor: Colors.redAccent,
                        inactiveTrackColor: Colors.orange,
                      )
                    ],
                  ),

                  Divider(
                    color: Colors.grey,
                    height: 5,
                  ),
                  InkWell(
                    child: Padding(
                      padding: EdgeInsets.all(10),
                      child: Row(
                        mainAxisAlignment: MainAxisAlignment.spaceBetween,
                        children: [
                          Text("Place Picker Toolbar Color"),
                          Text(PickerSettings().pickerToolbarColor.toString())
                        ],
                      ),
                    ),
                    onTap: () {
                      showDialog(
                        context: context,
                        builder: (_) => AlertDialog(
                          title: const Text('Pick a color!'),
                          content: SingleChildScrollView(
                            child: BlockPicker(
                              pickerColor: pickerToolbarColor,
                              onColorChanged: (color) {
                                setState(() {
                                  var hex = '#${color.value.toRadixString(16)}';
                                  PickerSettings().pickerToolbarColor = hex;
                                  //print(hex);
                                });
                              },
                            ),
                          ),
                          actions: <Widget>[
                            FlatButton(
                              child: const Text('Got it'),
                              onPressed: () {
                                Navigator.of(context).pop();
                              },
                            ),
                          ],
                        ),
                      );
                    },
                  ),
                  Divider(
                    color: Colors.grey,
                    height: 5,
                  ),
                  InkWell(
                    child: Padding(
                      padding: EdgeInsets.all(10),
                      child: Row(
                        mainAxisAlignment: MainAxisAlignment.spaceBetween,
                        children: [
                          Text("Address TextColor"),
                          Text(PickerSettings().addressTextColor.toString())
                        ],
                      ),
                    ),
                    onTap: () {
                      showDialog(
                        context: context,
                        builder: (_) => AlertDialog(
                          title: const Text('Pick a color!'),
                          content: SingleChildScrollView(
                            child: BlockPicker(
                              pickerColor: addressTextColor,
                              onColorChanged: (color) {
                                setState(() {
                                  var hex = '#${color.value.toRadixString(16)}';
                                  PickerSettings().addressTextColor = hex;
                                  //print(hex);
                                });
                              },
                            ),
                          ),
                          actions: <Widget>[
                            FlatButton(
                              child: const Text('Got it'),
                              onPressed: () {
                                Navigator.of(context).pop();
                              },
                            ),
                          ],
                        ),
                      );
                    },
                  ),
                  Divider(
                    color: Colors.grey,
                    height: 5,
                  ),
                  InkWell(
                    child: Padding(
                      padding: EdgeInsets.all(10),
                      child: Row(
                        mainAxisAlignment: MainAxisAlignment.spaceBetween,
                        children: [
                          Text("Info BottomView BackgroundColor"),
                          Text(PickerSettings().infoBottomViewBackgroundColor.toString())
                        ],
                      ),
                    ),
                    onTap: () {
                      showDialog(
                        context: context,
                        builder: (_) => AlertDialog(
                          title: const Text('Pick a color!'),
                          content: SingleChildScrollView(
                            child: BlockPicker(
                              pickerColor: infoBottomViewBackground,
                              onColorChanged: (color) {
                                setState(() {
                                  var hex = '#${color.value.toRadixString(16)}';
                                  PickerSettings().infoBottomViewBackgroundColor = hex;
                                  //print(hex);
                                });
                              },
                            ),
                          ),
                          actions: <Widget>[
                            FlatButton(
                              child: const Text('Got it'),
                              onPressed: () {
                                Navigator.of(context).pop();
                              },
                            ),
                          ],
                        ),
                      );
                    },
                  ),
                  Divider(
                    color: Colors.grey,
                    height: 5,
                  ),
                  InkWell(
                    child: Padding(
                      padding: EdgeInsets.all(10),
                      child: Row(
                        mainAxisAlignment: MainAxisAlignment.spaceBetween,
                        children: [
                          Text("Place Name Label TextColor"),
                          Text(PickerSettings().placeNameLabelTextColor.toString())
                        ],
                      ),
                    ),
                    onTap: () {
                      showDialog(
                        context: context,
                        builder: (_) => AlertDialog(
                          title: const Text('Pick a color!'),
                          content: SingleChildScrollView(
                            child: BlockPicker(
                              pickerColor: labelTextColor,
                              onColorChanged: (color) {
                                setState(() {
                                  var hex = '#${color.value.toRadixString(16)}';
                                  PickerSettings().placeNameLabelTextColor = hex;
                                  //print(hex);
                                });
                              },
                            ),
                          ),
                          actions: <Widget>[
                            FlatButton(
                              child: const Text('Got it'),
                              onPressed: () {
                                Navigator.of(context).pop();
                              },
                            ),
                          ],
                        ),
                      );
                    },
                  ),
                  Divider(
                    color: Colors.grey,
                    height: 5,
                  ),
                  Row(
                    mainAxisAlignment: MainAxisAlignment.spaceBetween,
                    children: [
                      Text("Map Max Zoom"),
                      Container(
                          width: 80,
                          child: TextFormField(
                            initialValue:
                            PickerSettings().mapMaxZoom.toString(),
                            maxLength: 2,
                            onChanged: (text) {
                              PickerSettings().mapMaxZoom =
                                  double.parse(text);
                            },
                            keyboardType: TextInputType.number,
                            decoration: InputDecoration(
                              border: OutlineInputBorder(),
                              hintText: "Map map zoom",
                            ),
                          )),
                    ],
                  ),
                  Divider(
                    color: Colors.grey,
                    height: 5,
                  ),
                  Row(
                    mainAxisAlignment: MainAxisAlignment.spaceBetween,
                    children: [
                      Text("Map Min Zoom"),
                      Container(
                          width: 80,
                          child: TextFormField(
                            initialValue:
                            PickerSettings().mapMinZoom.toString(),
                            maxLength: 2,
                            onChanged: (text) {
                              PickerSettings().mapMinZoom =
                                  double.parse(text);
                            },
                            keyboardType: TextInputType.number,
                            decoration: InputDecoration(
                              border: OutlineInputBorder(),
                              hintText: "Map Min zoom",
                            ),
                          )),
                    ],
                  ),
                  Divider(
                    color: Colors.grey,
                    height: 5,
                  ),
                  Text("AutoComplete Widget Settings",style: TextStyle(fontWeight: FontWeight.bold),),

                  Row(
                    mainAxisAlignment: MainAxisAlignment.spaceBetween,
                    children: [
                      Text("Tokenize Address"),
                      Switch(
                        onChanged: (bool value) {
                          PickerSettings().tokenizeAddress = value;
                          print(value);
                          setState(() {
                            isTokenizeAddress = value;
                          });
                        },
                        value: isTokenizeAddress,
                        activeColor: Colors.blue,
                        activeTrackColor: Colors.yellow,
                        inactiveThumbColor: Colors.redAccent,
                        inactiveTrackColor: Colors.orange,
                      )
                    ],
                  ),
                  Divider(
                    color: Colors.grey,
                    height: 5,
                  ),
                  Row(
                    mainAxisAlignment: MainAxisAlignment.spaceBetween,
                    children: [
                      Text("Save History"),
                      Switch(
                        onChanged: (bool value) {
                          PickerSettings().saveHistory = value;
                          print(value);
                          setState(() {
                            isSaveHistory = value;
                          });
                        },
                        value: isSaveHistory,
                        activeColor: Colors.blue,
                        activeTrackColor: Colors.yellow,
                        inactiveThumbColor: Colors.redAccent,
                        inactiveTrackColor: Colors.orange,
                      )
                    ],
                  ),

                  Divider(
                    color: Colors.grey,
                    height: 5,
                  ),
                  Row(
                    mainAxisAlignment: MainAxisAlignment.spaceBetween,
                    children: [
                      Text("History Count"),
                      Container(
                          width: 80,
                          child: TextFormField(
                            initialValue:
                            PickerSettings().historyCount.toString(),
                            maxLength: 3,
                            onChanged: (text) {
                              PickerSettings().historyCount =
                                  int.parse(text);
                            },
                            keyboardType: TextInputType.number,
                            decoration: InputDecoration(
                              border: OutlineInputBorder(),
                              hintText: "History Count",
                            ),
                          )),
                    ],
                  ),
                  Divider(
                    color: Colors.grey,
                    height: 5,
                  ),
                  Row(
                    mainAxisAlignment: MainAxisAlignment.spaceBetween,
                    children: [
                      Text("attributionHorizontalAlignment"),
                      RadioGroup<String?>.builder(
                        groupValue: getLabel(PickerSettings().attributionHorizontalAlignment),
                        onChanged: (value) => setState(() {
                          switch (value) {
                            case "Left":
                              PickerSettings()
                                  .attributionHorizontalAlignment =
                                  PlaceOptions.GRAVITY_LEFT;
                              break;
                            case "Center":
                              PickerSettings()
                                  .attributionHorizontalAlignment =
                                  PlaceOptions.GRAVITY_CENTER;
                              break;
                            case "Right":
                              PickerSettings()
                                  .attributionHorizontalAlignment =
                                  PlaceOptions.GRAVITY_RIGHT;
                              break;
                          }
                        }),
                        items: ["Left", "Center", "Right"],
                        itemBuilder: (item) => RadioButtonBuilder(
                          item!,
                        ),
                      ),
                    ],
                  ),
                  Divider(
                    color: Colors.grey,
                    height: 5,
                  ),
                  Row(
                    mainAxisAlignment: MainAxisAlignment.spaceBetween,
                    children: [
                      Text("attributionVerticalAlignment"),
                      RadioGroup<String?>.builder(
                        groupValue: getLabel(PickerSettings()
                            .attributionVerticalAlignment),
                        onChanged: (value) => setState(() {
                          switch (value) {
                            case "Top":
                              PickerSettings()
                                  .attributionVerticalAlignment =
                                  PlaceOptions.GRAVITY_TOP;
                              break;
                            case "Bottom":
                              PickerSettings()
                                  .attributionVerticalAlignment =
                                  PlaceOptions.GRAVITY_BOTTOM;
                              break;
                          }
                        }),
                        items: ["Top", "Bottom"],
                        itemBuilder: (item) => RadioButtonBuilder(
                          item!,
                        ),
                      ),
                    ],
                  ),
                  Divider(
                    color: Colors.grey,
                    height: 5,
                  ),
                  Row(
                    mainAxisAlignment: MainAxisAlignment.spaceBetween,
                    children: [
                      Text("Logo Size"),
                      RadioGroup<String?>.builder(
                        groupValue: getLabel(PickerSettings().logoSize),
                        onChanged: (value) => setState(() {
                          switch (value) {
                            case "Small":
                              PickerSettings().logoSize =
                                  PlaceOptions.SIZE_SMALL;
                              break;
                            case "Medium":
                              PickerSettings().logoSize =
                                  PlaceOptions.SIZE_MEDIUM;
                              break;
                            case "Large":
                              PickerSettings().logoSize =
                                  PlaceOptions.SIZE_LARGE;
                              break;
                          }
                        }),
                        items: ["Small", "Medium", "Large"],
                        itemBuilder: (item) => RadioButtonBuilder(
                          item!,
                        ),
                      ),
                    ],
                  ),
                  Divider(
                    color: Colors.grey,
                    height: 5,
                  ),
                  Row(
                    mainAxisAlignment: MainAxisAlignment.spaceBetween,
                    children: [
                      Text("Filter"),
                      Container(
                          width: 150,
                          child: TextFormField(
                            initialValue: PickerSettings().filter,
                            onChanged: (text) {
                              PickerSettings().filter = text;
                            },
                            decoration: InputDecoration(
                              border: OutlineInputBorder(),
                              hintText: "Filter",
                            ),
                          )),
                    ],
                  ),
                  Divider(
                    color: Colors.grey,
                    height: 5,
                  ),
                  Row(
                    mainAxisAlignment: MainAxisAlignment.spaceBetween,
                    children: [
                      Text("Hint"),
                      Container(
                          width: 150,
                          child: TextFormField(
                            initialValue: PickerSettings().hint,
                            onChanged: (text) {
                              PickerSettings().hint = text;
                            },
                            decoration: InputDecoration(
                              border: OutlineInputBorder(),
                              hintText: "Hint",
                            ),
                          )),
                    ],
                  ),
                  Divider(
                    color: Colors.grey,
                    height: 5,
                  ),
                  Row(
                    mainAxisAlignment: MainAxisAlignment.spaceBetween,
                    children: [
                      Text("POD"),
                      Container(
                          width: 150,
                          child: TextFormField(
                            initialValue: PickerSettings().pod,
                            onChanged: (text) {
                              PickerSettings().pod = text;
                            },
                            decoration: InputDecoration(
                              border: OutlineInputBorder(),
                              hintText: "POD",
                            ),
                          )),
                    ],
                  ),
                  Divider(
                    color: Colors.grey,
                    height: 5,
                  ),
                  InkWell(
                    child: Padding(
                      padding: EdgeInsets.all(10),
                      child: Row(
                        mainAxisAlignment: MainAxisAlignment.spaceBetween,
                        children: [
                          Text("Background Color"),
                          Text(PickerSettings().backgroundColor.toString())
                        ],
                      ),
                    ),
                    onTap: () {
                      showDialog(
                        context: context,
                        builder: (_) => AlertDialog(
                          title: const Text('Pick a color!'),
                          content: SingleChildScrollView(
                            child: BlockPicker(
                              pickerColor: backgroundColor,
                              onColorChanged: (color) {
                                setState(() {
                                  var hex = '#${color.value.toRadixString(16)}';
                                  PickerSettings().backgroundColor = hex;
                                  //print(hex);
                                });
                              },
                            ),
                          ),
                          actions: <Widget>[
                            FlatButton(
                              child: const Text('Got it'),
                              onPressed: () {
                                Navigator.of(context).pop();
                              },
                            ),
                          ],
                        ),
                      );
                    },
                  ),
                  Divider(
                    color: Colors.grey,
                    height: 5,
                  ),
                  InkWell(
                    child: Padding(
                      padding: EdgeInsets.all(10),
                      child: Row(
                        mainAxisAlignment: MainAxisAlignment.spaceBetween,
                        children: [
                          Text("Toolbar Color"),
                          Text(PickerSettings().toolbarColor.toString())
                        ],
                      ),
                    ),
                    onTap: () {
                      showDialog(
                        context: context,
                        builder: (_) => AlertDialog(
                          title: const Text('Pick a color!'),
                          content: SingleChildScrollView(
                            child: BlockPicker(
                              pickerColor: toolbarColor,
                              onColorChanged: (color) {
                                setState(() {
                                  var hex = '#${color.value.toRadixString(16)}';
                                  PickerSettings().toolbarColor = hex;
                                  //print(hex);
                                });
                              },
                            ),
                          ),
                          actions: <Widget>[
                            FlatButton(
                              child: const Text('Got it'),
                              onPressed: () {
                                Navigator.of(context).pop();
                              },
                            ),
                          ],
                        ),
                      );
                    },
                  ),
                  Divider(
                    color: Colors.grey,
                    height: 5,
                  ),
                  Row(
                    mainAxisAlignment: MainAxisAlignment.spaceBetween,
                    children: [
                      Text("Zoom"),
                      Container(
                          width: 150,
                          child: TextFormField(
                            initialValue: PickerSettings().zoom.toString(),
                            onChanged: (text) {
                              PickerSettings().zoom = double.parse(text);
                            },
                            keyboardType:TextInputType.number ,
                            decoration: InputDecoration(
                              border: OutlineInputBorder(),
                              hintText: "zoom",
                            ),
                          )),
                    ],
                  ),
                  Divider(
                    color: Colors.grey,
                    height: 5,
                  ),
                  Row(
                    mainAxisAlignment: MainAxisAlignment.spaceBetween,
                    children: [
                      Text("Location"),
                      Container(
                          width: 150,
                          child: TextFormField(
                            initialValue: PickerSettings().locationLat.toString(),
                            onChanged: (text) {
                              PickerSettings().locationLat = double.parse(text);
                            },
                            keyboardType:TextInputType.number ,
                            decoration: InputDecoration(
                              border: OutlineInputBorder(),
                              hintText: "Lat",
                            ),
                          )),
                      Container(
                          width: 150,
                          child: TextFormField(
                            initialValue: PickerSettings().locationLng.toString(),
                            onChanged: (text) {
                              PickerSettings().locationLng = double.parse(text);
                            },
                            keyboardType:TextInputType.number ,
                            decoration: InputDecoration(
                              border: OutlineInputBorder(),
                              hintText: "Lng",
                            ),
                          )),
                    ],
                  ),
                ]),
              ),
            )));
  }

  String? getLabel(int data) {
    switch (data) {
      case 1:
        return "Left";
      case 2:
        return "Center";
      case 3:
        return "Right";
      case 4:
        return "Top";
      case 5:
        return "Bottom";
      case 6:
        return "Small";
      case 7:
        return "Medium";
      case 8:
        return "Large";
    }
    return null;
  }
}
