import 'dart:convert';
import 'dart:typed_data';

import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:mapmyindia_place_flutter_example/pickerSettings.dart';
import 'package:mapmyindia_place_widget/mapmyindia_place_widget.dart';

class PlacePickerWidget extends StatefulWidget {
  @override
  State<StatefulWidget> createState() {
    return PlacePickerState();
  }
}

class PlacePickerState extends State {
  ReverseGeocodePlace _place = ReverseGeocodePlace();

  // Platform messages are asynchronous, so we initialize in an async method.
  Future<void> initPlatformState() async {
    ReverseGeocodePlace place;
    PickerSettings settings = PickerSettings();
    // Platform messages may fail, so we use a try/catch PlatformException.
    try {
      final ByteData bytes = await rootBundle.load("assets/symbols/custom-icon.png");
      final Uint8List list = bytes.buffer.asUint8List();
      final Color redColor= Colors.red;
      final LatLng customInitialCoordinate = LatLng(28.705436, 77.101514);

      final LatLngBounds bounds = LatLngBounds(northeast: LatLng(28.705436, 77.101514), southwest: LatLng(28.703900, 77.100462));
      PickerOption option = PickerOption(includeSearch: settings.includeSearch,
          infoBottomViewBackgroundColor: settings.infoBottomViewBackgroundColor,
           placeNameLabelTextColor: settings.placeNameLabelTextColor,
          startingBounds: bounds,
          addressTextColor: settings.addressTextColor,
          showMarkerShadow: settings.showMarkerShadow,
          toolbarColor: settings.pickerToolbarColor,
          includeDeviceLocationButton: settings.includeDeviceLocationButton,
          mapMinZoom: settings.mapMinZoom,
          mapMaxZoom: settings.mapMaxZoom,
          placeOptions: PlaceOptions(enableTextSearch: true,
              hint: settings.hint,
              attributionHorizontalAlignment: settings.attributionHorizontalAlignment,
              historyCount: settings.historyCount,
              pod: settings.pod!=null?settings.pod:null,
              backgroundColor: settings.backgroundColor,
              toolbarColor: settings.toolbarColor,
              saveHistory: settings.saveHistory,
              tokenizeAddress: settings.tokenizeAddress,
              zoom: settings.zoom!=null?settings.zoom:null,
              logoSize: settings.logoSize,
              filter: settings.filter!=null?settings.filter:null,
              location: settings.locationLat!=null&&settings.locationLng!=null?LatLng(settings.locationLat!,settings.locationLng!):null,
              attributionVerticalAlignment: settings.attributionVerticalAlignment));
      place = await openPlacePicker(option);
    } on PlatformException {
      place = ReverseGeocodePlace();
    }
    print(json.encode(place.toJson()));

    // // If the widget was removed from the tree while the asynchronous platform
    // // message was in flight, we want to discard the reply rather than calling
    // // setState to update our non-existent appearance.
    // if (!mounted) return;
    //
    setState(() {
      _place = place;
    });
  }

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
        home: Scaffold(
            appBar: AppBar(
              title: const Text('Place Search'),
              actions: <Widget>[
                IconButton(
                  icon: Icon(
                    Icons.settings,
                    color: Colors.white,
                  ),
                  onPressed: () {
                    Navigator.pushNamed(context, '/PickerSettings');
                  },
                )
              ],
            ),
            body: Center(child: Column(children: [
              SizedBox(height: 20,),
              Text(_place.formattedAddress == null? 'Address: ':'Address: ${_place.formattedAddress}' ),
              SizedBox(height: 20,),
              TextButton(onPressed: initPlatformState ,child:Text("Open Place picker")),
            ]))));
  }
}
