import 'dart:convert';

import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:mapmyindia_gl/mapmyindia_gl.dart';
import 'package:mapmyindia_place_flutter_example/placeSearchSettings.dart';
import 'package:mapmyindia_place_widget/mapmyindia_place_widget.dart';

class PlaceSearchWidget extends StatefulWidget {
  @override
  State<StatefulWidget> createState() {
    return PlaceSearchWidgetState();
  }
}

class PlaceSearchWidgetState extends State {
  ELocation _eLocation = ELocation();

  @override
  void initState() {
    super.initState();
  }

  // Platform messages are asynchronous, so we initialize in an async method.
  Future<void> initPlatformState() async {
    ELocation eLocation;
    PlaceSearchSettings settings = PlaceSearchSettings();
    // Platform messages may fail, so we use a try/catch PlatformException.
    try {
      AutocompleteResult result = await openPlaceAutocomplete(PlaceOptions(
          enableTextSearch: true,
          hint: settings.hint,
          attributionHorizontalAlignment:
              settings.attributionHorizontalAlignment,
          historyCount: settings.historyCount,
          pod: settings.pod != null ? settings.pod : null,
          backgroundColor: settings.backgroundColor,
          toolbarColor: settings.toolbarColor,
          minCharactersForSearch: 2,
          saveHistory: settings.saveHistory,
          tokenizeAddress: settings.tokenizeAddress,
          zoom: settings.zoom != null ? settings.zoom : null,
          logoSize: settings.logoSize,
          filter: settings.filter != null ? settings.filter : null,
          location: settings.locationLat != null && settings.locationLng != null
              ? LatLng(settings.locationLat!, settings.locationLng!)
              : null,
          attributionVerticalAlignment: settings.attributionVerticalAlignment));
      if (result.eLocation != null) {
        eLocation = result.eLocation!;
      } else {
        eLocation = ELocation();
      }
    } on PlatformException {
      eLocation = ELocation();
    }
    print(json.encode(eLocation.toJson()));

    // If the widget was removed from the tree while the asynchronous platform
    // message was in flight, we want to discard the reply rather than calling
    // setState to update our non-existent appearance.
    if (!mounted) return;

    setState(() {
      _eLocation = eLocation;
    });
  }

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      home: Scaffold(
        appBar: AppBar(
          title: const Text('Place Search'),
          actions: <Widget>[
            IconButton(
              icon: Icon(
                Icons.settings,
                color: Colors.white,
              ),
              onPressed: () {
                Navigator.pushNamed(context, '/SearchSettings');
              },
            )
          ],
        ),
        body: Center(
            child: Column(children: [
          SizedBox(
            height: 20,
          ),
          Text(_eLocation.eLoc == null ? 'ELoc: ' : 'ELoc: ${_eLocation.eLoc}'),
          SizedBox(
            height: 20,
          ),
          Text(_eLocation.placeName == null
              ? 'Place Name: '
              : 'Place Name: ${_eLocation.placeName}'),
          SizedBox(
            height: 20,
          ),
          Text(_eLocation.placeAddress == null
              ? 'Place Address: '
              : 'Place Address: ${_eLocation.placeAddress}'),
          SizedBox(
            height: 20,
          ),
          Text(_eLocation.latitude == null
              ? 'Latitude: '
              : 'Latitude: ${_eLocation.latitude}'),
          SizedBox(
            height: 20,
          ),
          Text(_eLocation.longitude == null
              ? 'Longitude: '
              : 'Longitude: ${_eLocation.longitude}'),
          SizedBox(
            height: 20,
          ),
          Text(_eLocation.type == null ? 'Type: ' : 'Type: ${_eLocation.type}'),
          SizedBox(
            height: 20,
          ),
          Text(_eLocation.entryLatitude == null
              ? 'Entry Latitude: '
              : 'Entry Latitude: ${_eLocation.entryLatitude?.toString()}'),
          SizedBox(
            height: 20,
          ),
          Text(_eLocation.entryLongitude == null
              ? 'Entry Longitude: '
              : 'Entry Longitude: ${_eLocation.entryLongitude?.toString()}'),
          SizedBox(
            height: 20,
          ),
          Text(_eLocation.orderIndex == null
              ? 'Order Index: '
              : 'Order Index: ${_eLocation.orderIndex?.toString()}'),
          SizedBox(
            height: 20,
          ),
          Text(_eLocation.keywords == null
              ? 'Keywords: '
              : 'Keywords: ${_eLocation.keywords?.toString()}'),
          SizedBox(
            height: 20,
          ),
          Text(_eLocation.typeX == null
              ? 'Type X: '
              : 'Type X: ${_eLocation.typeX}'),
          SizedBox(
            height: 20,
          ),
          TextButton(
              onPressed: initPlatformState,
              child: Text("Open Place Autocomplete")),
        ])
            //    RaisedButton(onPressed: initPlatformState ,child: Text("Go to native"),)
            ),
      ),
    );
  }
}
