//
//  PlacePickerViewController.swift
//  mapmyindia_place_flutter
//
//  Created by CEINFO on 11/12/20.
//

import UIKit
import MapmyIndiaUIWidgets
import MapmyIndiaAPIKit
import MapmyIndiaMaps


protocol PlacePickerViewControllerDelegate: class {

    func didPickedLocation(viewController: PlacePickerViewController, placemark: MapmyIndiaGeocodedPlacemark)

    func didReverseGeocode(viewController: PlacePickerViewController, placemark: MapmyIndiaGeocodedPlacemark)

    func didCancelPlacePicker(pickerController: PlacePickerViewController)


}


class PlacePickerViewController: UIViewController {
    var placePicker: PlacePickerView!
    var list : [String: Any]?


    public var placemark : MapmyIndiaGeocodedPlacemark!
    public weak var delegate: PlacePickerViewControllerDelegate?
    override func viewDidLoad() {
        super.viewDidLoad()

    }
    
    public init(nibName nibNameOrNil: String?, bundle nibBundleOrNil: Bundle?, list: [String : Any]) {
        super.init(nibName: nil, bundle: nil)
        placePicker = PlacePickerView(frame: self.view.bounds, parentViewController: self)
        let util = Utils()
        util.getplacePickerOptions(argsLists: list, placePicker: placePicker)
        placePicker.delegate = self
        self.view.addSubview(placePicker)
        

    }
    
    required init?(coder: NSCoder) {
        fatalError("init(coder:) has not been implemented")
    }
    
/*    private func getplacePickerOptions(argsLists : [String : Any]){
        let   list = (argsLists.first!.value) as! [String : Any]

        if list.keys.contains("includeSearch"){
            placePicker.isSearchButtonHidden = !(list["includeSearch"] as! Bool)
        }
        
        if list.keys.contains("marker"){
            print(argsLists["marker"] as Any)
            let marker = list["marker"] as! [String: Any]
            let myFlutterData: FlutterStandardTypedData = marker["image"] as! FlutterStandardTypedData
            let myData = Data(myFlutterData.data)
            let myUInt8bytes: [UInt8] = myData.toArray(type: UInt8.self)
            let data = NSData(bytes: myUInt8bytes, length: myUInt8bytes.count)
            let image = UIImage(data: data as Data)
            placePicker.markerView = UIImageView(image: image)
            
        }
        
        if list.keys.contains("statingCameraPosition") {
            let mapCamera = fromDict(list["statingCameraPosition"] as! [String: Any], mapView: placePicker.mapView)
            if mapCamera != nil {
                placePicker.isInitializeWithCustomLocation = true
                placePicker.mapView.setCamera(mapCamera!, animated: false)
            }
        }

        if list.keys.contains("startingBounds") {
            let array = list["startingBounds"] as! [[Double]]
            let southwest = CLLocationCoordinate2D(latitude: array[0][0], longitude: array[0][1])
            let northeast = CLLocationCoordinate2D(latitude: array[1][0], longitude: array[1][1])
              let bounds = MGLCoordinateBounds(sw: southwest, ne: northeast)
            placePicker.isInitializeWithCustomLocation = true
            placePicker.mapView.setVisibleCoordinateBounds(bounds, animated: false)
        }

        if(list.keys.contains("mapMinZoom")) {
            placePicker.mapView.minimumZoomLevel = list["mapMinZoom"] as! Double
        }

        if(list.keys.contains("mapMaxZoom")) {
            placePicker.mapView.maximumZoomLevel = list["mapMaxZoom"] as! Double
        }


        if list.keys.contains("toolbarColor"){
                let hexColor = (list["toolbarColor"])
            print(hexColor as! String)
                placePicker.searchButtonBackgroundColor = hexStringToUIColor(hex: hexColor as! String)
        }

        if list.keys.contains("searchPlaceOption") {
            placePicker.autocompleteFilter = autocompleteFilter(options: list["searchPlaceOption"] as! [String: Any])
            autocompleteProperties(options: list["searchPlaceOption"] as! [String: Any])
        }
        
        if list.keys.contains("placeNameLabelTextColor"){
            placePicker.placeNameLabelTextColor = hexStringToUIColor(hex: list["placeNameLabelTextColor"] as! String)
        }
        if list.keys.contains("pickerButtonTitleColor"){
            placePicker.pickerButtonTitleColor = hexStringToUIColor(hex: list["pickerButtonTitleColor"] as! String)
        }
        if list.keys.contains("pickerButtonTitle"){
            placePicker.pickerButtonTitle = "\(list["pickerButtonTitle"] as! String)"
        }
        if list.keys.contains("pickerButtonBackgroundColor"){
            placePicker.pickerButtonBackgroundColor = hexStringToUIColor(hex: list["pickerButtonBackgroundColor"] as! String)
        }
        if list.keys.contains("infoBottomViewBackgroundColor"){
            placePicker.infoBottomViewBackgroundColor = hexStringToUIColor(hex: list["infoBottomViewBackgroundColor"] as! String)
        }
        
    }
    
    func autocompleteProperties(options: [String: Any]) {
        if options.keys.contains("historyCount") {
            HistoryCountToShow = options["historyCount"] as! Int
        }
        if options.keys.contains("saveHistory") {
            IsHistoryEnabled = options["saveHistory"] as! Bool
        }
        if options.keys.contains("enableTextSearch") {
            IsTextSearchEnabledOnPressingEnterOrSearchKey = options["enableTextSearch"] as! Bool
        }
    }

    func autocompleteFilter(options: [String: Any]) -> MapmyIndiaAutocompleteFilter {
        let autocompleteFilter = MapmyIndiaAutocompleteFilter()
        if(options.keys.contains("location")) {
            let location = options["location"] as! [Double]
            autocompleteFilter.origin = CLLocation(latitude: location[0], longitude:location[1])
        }
        if(options.keys.contains("zoom")) {
            autocompleteFilter.zoom = options["zoom"] as? NSNumber
        }
        if(options.keys.contains("tokenizeAddress")) {
            autocompleteFilter.attributions = options["tokenizeAddress"] as! Bool
        }

        if(options.keys.contains("pod")) {
            autocompleteFilter.resultPlaceType = MMIPodTypeIdentifier(options["pod"] as! String)
        }
        return autocompleteFilter
    }

    func fromDict(_ dict: [String: Any], mapView: MapmyIndiaMapView) -> MGLMapCamera? {
        guard let target = dict["target"] as? [Double],
            let zoom = dict["zoom"] as? Double,
            let tilt = dict["tilt"] as? CGFloat,
            let bearing = dict["bearing"] as? Double else { return nil }
        let location = CLLocationCoordinate2D(latitude: target[0], longitude: target[1])
        let altitude = MGLAltitudeForZoomLevel(zoom, tilt, location.latitude, mapView.frame.size)
        return MGLMapCamera(lookingAtCenter: location, altitude: altitude, pitch: tilt, heading: bearing)
    }

    func hexStringToUIColor (hex:String) -> UIColor {
        var cString:String = hex.trimmingCharacters(in: .whitespacesAndNewlines).uppercased()

        if (cString.hasPrefix("#")) {
            cString.remove(at: cString.startIndex)
        }

        if ((cString.count) != 6) {
            return UIColor.gray
        }

        var rgbValue:UInt64 = 0
        Scanner(string: cString).scanHexInt64(&rgbValue)

        return UIColor(
            red: CGFloat((rgbValue & 0xFF0000) >> 16) / 255.0,
            green: CGFloat((rgbValue & 0x00FF00) >> 8) / 255.0,
            blue: CGFloat(rgbValue & 0x0000FF) / 255.0,
            alpha: CGFloat(1.0)
        )
    } */
}
extension Data {

    init<T>(fromArray values: [T]) {
        var values = values
        self.init(buffer: UnsafeBufferPointer(start: &values, count: values.count))
    }

    func toArray<T>(type: T.Type) -> [T] {
        return self.withUnsafeBytes {
            [T](UnsafeBufferPointer(start: $0, count: self.count/MemoryLayout<T>.stride))
        }
    }
}
extension PlacePickerViewController :  PlacePickerViewDelegate {
    func didFailedReverseGeocode(error: NSError?) {
        if let error = error {
            // failed for error
        } else {
            // No results found
        }
    }

    func didPickedLocation(placemark: MapmyIndiaGeocodedPlacemark) {
        self.delegate?.didPickedLocation(viewController: self, placemark: placemark)
        print("placeviewXon")
        self.placemark = placemark
    }

    func didReverseGeocode(placemark: MapmyIndiaGeocodedPlacemark) {
        self.delegate?.didReverseGeocode(viewController: self, placemark: placemark)

    }

    func didCancelPlacePicker() {

    }

}
