import Flutter
import UIKit
import MapmyIndiaAPIKit
import MapmyIndiaUIWidgets


public class SwiftMapmyindiaPlaceFlutterPlugin: NSObject, FlutterPlugin {
    var placePickerView: PlacePickerViewController!
    var result : FlutterResult!
    private var flutterViewController: FlutterViewController!
    private var autocompleteFilter : MapmyIndiaAutocompleteFilter!
    
    public static func register(with registrar: FlutterPluginRegistrar) {
        MapmyIndiaAccountManager.setAtlasGrantType("client_credentials")
        
        let channel = FlutterMethodChannel(name: "mapmyindia_place_flutter", binaryMessenger: registrar.messenger())
        let instance = SwiftMapmyindiaPlaceFlutterPlugin()
        registrar.addMethodCallDelegate(instance, channel: channel)
        
    }
    
    public func handle(_ call: FlutterMethodCall, result: @escaping FlutterResult) {
        
        flutterViewController = (UIApplication.shared.delegate?.window??.rootViewController) as? FlutterViewController
        // Your viewController
        if call.method == "openPlacePicker"{
            guard let args = call.arguments else {
                return
            }
            
            var argsLists: [String: Any]?
            argsLists = (args as! [String : Any])
            print((argsLists?.first!.value)!)
            
            self.placePickerView = PlacePickerViewController(nibName: nil, bundle: nil, list: argsLists!)
            placePickerView?.delegate = self
            placePickerView.modalPresentationStyle = .fullScreen
            flutterViewController?.present(placePickerView, animated: false, completion: nil)
            self.result = result
            
        }
        
        if call.method == "openPlaceAutocomplete"{
            guard let args = call.arguments else {
                return
            }
            
            var argsLists: [String: Any]?
            argsLists = (args as! [String : Any])
            print((argsLists?.first!.value)!)
            let util = Utils()
            let autocompleteViewController = MapmyIndiaAutocompleteViewController()
            autocompleteViewController.delegate = self
            util.getPlaceOptions(argsLists: argsLists!, autoCompleteVC: autocompleteViewController)
            autocompleteViewController.modalPresentationStyle = .overCurrentContext
            
            
            flutterViewController?.present(autocompleteViewController, animated: false, completion: nil)
            self.result = result
            
        }
        
    }
    
    
    
}

extension SwiftMapmyindiaPlaceFlutterPlugin: MapmyIndiaAutocompleteViewControllerDelegate{
    public func didAutocomplete(viewController: MapmyIndiaAutocompleteViewController, withSuggestion suggestion: MapmyIndiaSearchPrediction) {
        let data: [String: Any] = [
            "keyword": suggestion.keyword ?? "",
            "identifier": suggestion.identifier ?? "",
            "location": suggestion.location ?? "",
            "hyperLink": suggestion.hyperLink ?? "",
            "orderIndex": suggestion.orderIndex ?? "",
            "eLoc": suggestion.eLoc ?? ""
        ]
        if let theJSONData = try? JSONSerialization.data(
            withJSONObject: ["suggestedSearch": data],
            options: []) {
            let theJSONText = String(data: theJSONData,
                                     encoding: .ascii)
            
            self.result("\(theJSONText ?? "")")
        }
        
    }
    
    public func didAutocomplete(viewController: MapmyIndiaAutocompleteViewController, withPlace place: MapmyIndiaAtlasSuggestion) {
        
        var data : [String: Any] =  [String: Any]()
        if let eloc = place.eLoc {
            data["eLoc"] = eloc
        }
        if let placeName = place.placeName {
            data["placeName"] = placeName
        }
        if let placeAddress = place.placeAddress {
            data["placeAddress"] = placeAddress
        }
        if let longitude = place.longitude {
            data["longitude"] = "\(longitude)"
        }
        if let latitude = place.latitude {
            data["latitude"] = "\(latitude)"
        }
        if let type = place.type {
            data["type"] = type
        }
        if let entryLatitude = place.entryLatitude {
            data["entryLatitude"] = entryLatitude
        }
        if let entryLongitude = place.entryLongitude {
            data["entryLongitude"] = entryLongitude
        }
        if let orderIndex = place.orderIndex {
            data["orderIndex"] = orderIndex
        }
        if let keywords = place.keywords {
            data["keywords"] = keywords
        }
        if let typeX = place.typeX {
            data["typeX"] = typeX
        }
        if let distance = place.distance {
            data["distance"] = distance
        }
        
        if let addressToken = place.addressTokens {
            
            data["addressTokens"] = ["poi": addressToken.poi,
                                     "city": addressToken.city,
                                     "district":addressToken.district,
                                     "houseName": addressToken.houseName,
                                     "houseNumber": addressToken.houseNumber,
                                     "locality": addressToken.locality,
                                     "pincode": addressToken.pincode,
                                     "state": addressToken.state,
                                     "street": addressToken.street,
                                     "subDistrict": addressToken.subDistrict,
                                     "subLocality": addressToken.subLocality,
                                     "subSubLocality": addressToken.subSubLocality,
                                     "village": addressToken.village]
        }
        
        if let theJSONData = try? JSONSerialization.data(
            withJSONObject: ["eLocation": data],
            options: []) {
            let theJSONText = String(data: theJSONData,
                                     encoding: .ascii)
            
            self.result("\(theJSONText ?? "")")
        }
        
        
        
        
        
        
        
        
        flutterViewController.dismiss(animated: false, completion: nil)
        
    }
    
    public func didFailAutocomplete(viewController: MapmyIndiaAutocompleteViewController, withError error: NSError) {
        
    }
    
    public func wasCancelled(viewController: MapmyIndiaAutocompleteViewController) {
        
    }
    
    
}


extension SwiftMapmyindiaPlaceFlutterPlugin: PlacePickerViewControllerDelegate{
    func didPickedLocation(viewController: PlacePickerViewController, placemark: MapmyIndiaGeocodedPlacemark) {
        
        let data: [String: Any?] = [
            "area": placemark.area,
            "houseNumber": placemark.houseNumber,
            "houseName": placemark.houseName,
            "poi": placemark.poi,
            "poi_dist": placemark.poiDist,
            "street": placemark.street,
            "street_dist": placemark.streetDist,
            "subSubLocality": placemark.subSubLocality,
            "subLocality": placemark.subLocality,
            "locality": placemark.locality,
            "village": placemark.village,
            "subDistrict": placemark.subDistrict,
            "district": placemark.district,
            "city": placemark.city,
            "state": placemark.state,
            "pincode": placemark.pincode,
            "formatted_address": placemark.formattedAddress,
            "place_id": placemark.placeId,
            "lat": placemark.latitude,
            "lng": placemark.longitude
        ]
        
        
        
        do {
            if let theJSONData = try? JSONSerialization.data(
                withJSONObject: data,
                options: []) {
                let theJSONText = String(data: theJSONData,
                                         encoding: .ascii)
                self.result("\(theJSONText ?? "")")
            }
            
        } catch {
            print(error.localizedDescription)
        }
        flutterViewController.dismiss(animated: false, completion: nil)
        
        
    }
    
    func didReverseGeocode(viewController: PlacePickerViewController, placemark: MapmyIndiaGeocodedPlacemark) {
        
    }
    
    func didCancelPlacePicker(pickerController: PlacePickerViewController) {
        
    }
}



