//
//  Utils.swift
//  mapmyindia_place_flutter
//
//  Created by CEINFO on 17/12/20.
//

import Foundation
import UIKit
import MapmyIndiaUIWidgets
import MapmyIndiaAPIKit
import MapmyIndiaMaps
public class Utils: NSObject {
    
    func getplacePickerOptions(argsLists : [String : Any], placePicker: PlacePickerView) {
        let   list = (argsLists.first!.value) as! [String : Any]
        
        if list.keys.contains("includeSearch") {
            placePicker.isSearchButtonHidden = !(list["includeSearch"] as! Bool)
        }
        
        if list.keys.contains("marker") {
            print(argsLists["marker"] as Any)
            let marker = list["marker"] as! [String: Any]
            let myFlutterData: FlutterStandardTypedData = marker["image"] as! FlutterStandardTypedData
            let myData = Data(myFlutterData.data)
            let myUInt8bytes: [UInt8] = myData.toArray(type: UInt8.self)
            let data = NSData(bytes: myUInt8bytes, length: myUInt8bytes.count)
            let image = UIImage(data: data as Data)
            placePicker.markerView = UIImageView(image: image)
            
        }
        
        if list.keys.contains("statingCameraPosition") {
            let mapCamera = fromDict(list["statingCameraPosition"] as! [String: Any], mapView: placePicker.mapView)
            if mapCamera != nil {
                placePicker.isInitializeWithCustomLocation = true
                placePicker.mapView.setCamera(mapCamera!, animated: false)
            }
        }
        
        if list.keys.contains("startingBounds") {
            let array = list["startingBounds"] as! [[Double]]
            let southwest = CLLocationCoordinate2D(latitude: array[0][0], longitude: array[0][1])
            let northeast = CLLocationCoordinate2D(latitude: array[1][0], longitude: array[1][1])
            let bounds = MGLCoordinateBounds(sw: southwest, ne: northeast)
            placePicker.isInitializeWithCustomLocation = true
            placePicker.mapView.setVisibleCoordinateBounds(bounds, animated: false)
        }
        
        if(list.keys.contains("mapMinZoom")) {
            placePicker.mapView.minimumZoomLevel = list["mapMinZoom"] as! Double
        }
        
        if(list.keys.contains("mapMaxZoom")) {
            placePicker.mapView.maximumZoomLevel = list["mapMaxZoom"] as! Double
        }
        
        if list.keys.contains("toolbarColor") {
            let hexColor = (list["toolbarColor"])
            print(hexColor as! String)
            placePicker.searchButtonBackgroundColor = hexStringToUIColor(hex: hexColor as! String)
        }
        
        if list.keys.contains("searchPlaceOption") {
            placePicker.autocompleteFilter = autocompleteFilter(options: list["searchPlaceOption"] as! [String: Any])
            autocompleteProperties(options: list["searchPlaceOption"] as! [String: Any])
            placePicker.autocompleteAttributionSettings = mapmyIndiaAttributionsSettings(options: list["searchPlaceOption"] as! [String: Any])
        }
        
        if list.keys.contains("placeNameLabelTextColor") {
            placePicker.placeNameLabelTextColor = hexStringToUIColor(hex: list["placeNameLabelTextColor"] as! String)
        }
        
        if list.keys.contains("pickerButtonTitleColor") {
            placePicker.pickerButtonTitleColor = hexStringToUIColor(hex: list["pickerButtonTitleColor"] as! String)
        }
        
        if list.keys.contains("pickerButtonTitle"){
            placePicker.pickerButtonTitle = "\(list["pickerButtonTitle"] as! String)"
        }
        
        if list.keys.contains("pickerButtonBackgroundColor") {
            placePicker.pickerButtonBackgroundColor = hexStringToUIColor(hex: list["pickerButtonBackgroundColor"] as! String)
        }
        
        if list.keys.contains("infoBottomViewBackgroundColor") {
            placePicker.infoBottomViewBackgroundColor = hexStringToUIColor(hex: list["infoBottomViewBackgroundColor"] as! String)
        }
        
        if list.keys.contains("addressTextColor") {
            placePicker.addressLabelTextColor = hexStringToUIColor(hex: list["addressTextColor"] as! String)
        }
        
        if list.keys.contains("showMarkerShadow") {
            placePicker.isMarkerShadowViewHidden = !(list["showMarkerShadow"] as! Bool)
        }
        
        if list.keys.contains("includeDeviceLocationButton") {
            placePicker.isShowCurrentLocation = list["includeDeviceLocationButton"] as! Bool
        }
        if(list.keys.contains("toolbarTintColor")) {
            let color = hexStringToUIColor(hex: list["toolbarTintColor"] as! String)
            
            let searchBarTextAttributes = [
                NSAttributedString.Key.foregroundColor: color,
                NSAttributedString.Key.font: UIFont.systemFont(ofSize: UIFont.systemFontSize)
            ]
            UITextField.appearance(whenContainedInInstancesOf: [PlacePickerViewController.self]).defaultTextAttributes = searchBarTextAttributes
        }
    }
    
    func getPlaceOptions(argsLists: [String: Any], autoCompleteVC: MapmyIndiaAutocompleteViewController) {
        let   list = (argsLists.first!.value) as! [String : Any]
        
        if list.keys.contains("saveHistory") {
            IsHistoryEnabled = list["saveHistory"] as! Bool
        }
        
        if list.keys.contains("primaryTextColor"){
            autoCompleteVC.primaryTextColor = hexStringToUIColor(hex: list["primaryTextColor"] as! String)
        }
        
        if list.keys.contains("tintColor"){
            autoCompleteVC.tintColor = hexStringToUIColor(hex: list["tintColor"] as! String)
        }
        
        if list.keys.contains("tableCellSeparatorColor"){
            autoCompleteVC.tableCellSeparatorColor = hexStringToUIColor(hex: list["tableCellSeparatorColor"] as! String)
        }
        
        if list.keys.contains("primaryTextHighlightColor"){
            autoCompleteVC.primaryTextHighlightColor = hexStringToUIColor(hex: list["primaryTextHighlightColor"] as! String)
        }
        
        if list.keys.contains("historyCount") {
            HistoryCountToShow = list["historyCount"] as! Int
        }
        if list.keys.contains("enableTextSearch") {
            IsTextSearchEnabledOnPressingEnterOrSearchKey = list["enableTextSearch"] as! Bool
        }
        
        if list.keys.contains("backgroundColor"){
            autoCompleteVC.tableCellBackgroundColor = hexStringToUIColor(hex: list["backgroundColor"] as! String)
        }
        if list.keys.contains("toolbarColor") {
            let color = hexStringToUIColor(hex: list["toolbarColor"] as! String)
            UINavigationBar.appearance(whenContainedInInstancesOf: [MapmyIndiaAutocompleteViewController.self]).barTintColor = color
        }
        if(list.keys.contains("toolbarTintColor")) {
            let color = hexStringToUIColor(hex: list["toolbarTintColor"] as! String)
            
            let searchBarTextAttributes = [
                NSAttributedString.Key.foregroundColor: color,
                NSAttributedString.Key.font: UIFont.systemFont(ofSize: UIFont.systemFontSize)
            ]
            UITextField.appearance(whenContainedInInstancesOf: [MapmyIndiaAutocompleteViewController.self]).defaultTextAttributes = searchBarTextAttributes
        }
//
        if(list.keys.contains("minCharactersForSearch")) {
            MinimumNumberOfCharacterToStartSearch = list["minCharactersForSearch"] as! Int
        }
        
        autoCompleteVC.autocompleteFilter = autocompleteFilter(options: list )
        autoCompleteVC.attributionSettings = mapmyIndiaAttributionsSettings(options: list)
        

        if list.keys.contains("hint") {
            let placeHolderText = list["hint"] as! String
            UITextField.appearance(whenContainedInInstancesOf: [MapmyIndiaAutocompleteViewController.self]).placeholder = placeHolderText
        }
        
        
    }
    
    func autocompleteFilter(options: [String: Any]) -> MapmyIndiaAutocompleteFilter {
        let autocompleteFilter = MapmyIndiaAutocompleteFilter()
        if(options.keys.contains("location")) {
            let location = options["location"] as! [Double]
            autocompleteFilter.origin = CLLocation(latitude: location[0], longitude:location[1])
        }
        if(options.keys.contains("zoom")) {
            autocompleteFilter.zoom = options["zoom"] as? NSNumber
        }
        if(options.keys.contains("tokenizeAddress")) {
            autocompleteFilter.attributions = options["tokenizeAddress"] as! Bool
        }
        
        if(options.keys.contains("pod")) {
            autocompleteFilter.resultPlaceType = MMIPodTypeIdentifier(options["pod"] as! String)
        }
        
        if(options.keys.contains("filter")) {
            let filter = options["filter"] as! String
            if(filter.contains("bounds")) {
                let filterArray = filter.components(separatedBy: ":")
                let boundsArray = filterArray[1].components(separatedBy: ";")
                let firstBound = boundsArray[0].components(separatedBy: ",")
                let secondBound = boundsArray[1].components(separatedBy: ",")
                let firstLng=(firstBound[1] as NSString).doubleValue
                let firstLat=(firstBound[0] as NSString).doubleValue
                let secondLng=(secondBound[1] as NSString).doubleValue
                let secondLat=(secondBound[0] as NSString).doubleValue
                
                let southwest = CLLocationCoordinate2D(latitude: firstLat, longitude: firstLng)
                let northeast = CLLocationCoordinate2D(latitude: secondLat, longitude: secondLng)
                autocompleteFilter.searchAreaRestrictions = MapmyIndiaBoundsFilter(bounds: MapmyIndiaRectangularRegion(topLeft: northeast, bottomRight: southwest))
            } else if(filter.contains("cop")) {
                let filterArray = filter.components(separatedBy: ":")
                autocompleteFilter.searchAreaRestrictions = MapmyIndiaElocFilter(placeId: filterArray[1])
            }
        }
        return autocompleteFilter
    }
    
    func fromDict(_ dict: [String: Any], mapView: MapmyIndiaMapView) -> MGLMapCamera? {
        guard let target = dict["target"] as? [Double],
              let zoom = dict["zoom"] as? Double,
              let tilt = dict["tilt"] as? CGFloat,
              let bearing = dict["bearing"] as? Double else { return nil }
        let location = CLLocationCoordinate2D(latitude: target[0], longitude: target[1])
        let altitude = MGLAltitudeForZoomLevel(zoom, tilt, location.latitude, mapView.frame.size)
        return MGLMapCamera(lookingAtCenter: location, altitude: altitude, pitch: tilt, heading: bearing)
    }
    
    func mapmyIndiaAttributionsSettings(options: [String: Any]) -> MapmyIndiaAttributionsSettings {
        let attribution = MapmyIndiaAttributionsSettings()
        
        if options.keys.contains("attributionHorizontalAlignment") {
            switch options["attributionHorizontalAlignment"] as! Int {
            case 1:
                attribution.attributionHorizontalContentAlignment = .left
            case 2:
                attribution.attributionHorizontalContentAlignment = .center
            case 3:
                attribution.attributionHorizontalContentAlignment = .right
            default:
                attribution.attributionHorizontalContentAlignment = .center
            }
        }
        
        if options.keys.contains("attributionVerticalAlignment") {
            switch options["attributionVerticalAlignment"] as! Int {
            case 4:
                attribution.attributionVerticalPlacement = .before
            case 5:
                attribution.attributionVerticalPlacement = .after
            default:
                attribution.attributionVerticalPlacement = .before
            }
        }
        
        if options.keys.contains("logoSize") {
            switch options["logoSize"] as! Int {
            case 6:
                attribution.attributionSize = .small
            case 7:
                attribution.attributionSize = .medium
            case 8:
                attribution.attributionSize = .large
            default:
                attribution.attributionSize = .small
            }
        }
        return attribution
    }
    
    func hexStringToUIColor (hex:String) -> UIColor {
        var cString:String = hex.trimmingCharacters(in: .whitespacesAndNewlines).uppercased()
        
        if (cString.hasPrefix("#")) {
            cString.remove(at: cString.startIndex)
        }
        
        if ((cString.count) != 6) {
            return UIColor.gray
        }
        
        var rgbValue:UInt64 = 0
        Scanner(string: cString).scanHexInt64(&rgbValue)
        
        return UIColor(
            red: CGFloat((rgbValue & 0xFF0000) >> 16) / 255.0,
            green: CGFloat((rgbValue & 0x00FF00) >> 8) / 255.0,
            blue: CGFloat(rgbValue & 0x0000FF) / 255.0,
            alpha: CGFloat(1.0)
        )
    }
    
    func autocompleteProperties(options: [String: Any]) {
        if options.keys.contains("historyCount") {
            HistoryCountToShow = options["historyCount"] as! Int
        }
        if options.keys.contains("saveHistory") {
            IsHistoryEnabled = options["saveHistory"] as! Bool
        }
        if options.keys.contains("enableTextSearch") {
            IsTextSearchEnabledOnPressingEnterOrSearchKey = options["enableTextSearch"] as! Bool
        }
    }
    
}
