part of mapmyindia_place_widget;

class PickerOption {
  /// To hide and show current location button
  final bool? includeDeviceLocationButton;

  /// To hide and show Search
  final bool? includeSearch;

  /// To set Maximum Map Zoom
  final double? mapMaxZoom;

  /// To set Minimum Map Zoom
  final double? mapMinZoom;

  /// To set search widget settings
  final PlaceOptions? placeOptions;

  /// To set Toolbar color
  final String? toolbarColor;

  /// To set marker Image
  final Uint8List? marker;

  /// To set Initial Camera Position
  final CameraPosition? statingCameraPosition;

  /// To set Initial Camera Bounds
  final LatLngBounds? startingBounds;

  /// To set Toolbar Text and icons color
  final String? toolbarTintColor;

  /// To set Place Name label Text Color
  final String? placeNameLabelTextColor;

  /// To set Done button text Color
  final String? pickerButtonTitleColor;

  ///To set Done button text
  final String? pickerButtonTitle;

  /// To set Done button Background color
  final String? pickerButtonBackgroundColor;

  /// To set Address label text color
  final String? addressTextColor;

  /// To hide and show Marker shadow
  final bool? showMarkerShadow;

  // ios proprities
  final Uint8List? searchButtonImage;
  final String? infoBottomViewBackgroundColor;

  PickerOption(
      {this.includeDeviceLocationButton,
      this.includeSearch,
      this.mapMaxZoom,
      this.mapMinZoom,
      this.placeOptions,
      this.toolbarColor,
      this.marker,
      this.statingCameraPosition,
      this.startingBounds,
      this.toolbarTintColor,
      this.placeNameLabelTextColor,
      this.pickerButtonTitleColor,
      this.pickerButtonTitle,
      this.pickerButtonBackgroundColor,
      this.addressTextColor,
      this.showMarkerShadow,

      // ios
      this.searchButtonImage,
      this.infoBottomViewBackgroundColor});

  Map<String, dynamic> toMap() {
    final Map<String, dynamic> optionsMap = <String, dynamic>{};

    void addIfNonNull(String fieldName, dynamic value) {
      if (value != null) {
        optionsMap[fieldName] = value;
      }
    }

    void addMapIfNonNull(String fieldName, Uint8List value) {
      if (value != null) {
        optionsMap[fieldName] = <String, dynamic>{
          'image': value,
          'length': value.length
        };
      }
    }

    addIfNonNull('includeDeviceLocationButton',
        includeDeviceLocationButton); //Android Only
    addIfNonNull('includeSearch', includeSearch);
    addIfNonNull('mapMaxZoom', mapMaxZoom);
    addIfNonNull('mapMinZoom', mapMinZoom);
    addIfNonNull('searchPlaceOption', placeOptions?.toMap());
    addIfNonNull('toolbarColor', toolbarColor);
    addIfNonNull('statingCameraPosition', statingCameraPosition?.toMap());
    addIfNonNull('startingBounds', startingBounds?.toList());
    if (marker != null) {
      addMapIfNonNull('marker', marker!);
    }
    addIfNonNull('toolbarTintColor', toolbarTintColor); //Android Only
    addIfNonNull("placeNameLabelTextColor", placeNameLabelTextColor);
    addIfNonNull("pickerButtonTitleColor", pickerButtonTitleColor);
    addIfNonNull("pickerButtonTitle", pickerButtonTitle);
    addIfNonNull("pickerButtonBackgroundColor", pickerButtonBackgroundColor);

    //new
    addIfNonNull('addressTextColor', addressTextColor);
    addIfNonNull('showMarkerShadow', showMarkerShadow);

    // ios
    addIfNonNull(
        "infoBottomViewBackgroundColor", infoBottomViewBackgroundColor);
    if (searchButtonImage != null) {
      addMapIfNonNull('searchButtonImage', searchButtonImage!);
    }

    return optionsMap;
  }
}
