part of mapmyindia_place_widget;

class PlaceOptions {
  static const int GRAVITY_LEFT = 1;
  static const int GRAVITY_CENTER = 2;
  static const int GRAVITY_RIGHT = 3;
  static const int GRAVITY_TOP = 4;
  static const int GRAVITY_BOTTOM = 5;
  static const int SIZE_SMALL = 6;
  static const int SIZE_MEDIUM = 7;
  static const int SIZE_LARGE = 8;

  /// To enable disable Text Search
  final bool? enableTextSearch;

  /// To set filter in Search
  final String? filter;

  /// To set hint on search bar
  final String? hint;

  /// To set Offline data count
  final int? historyCount;
  final int? limit;

  /// To set pod values in Search Request
  final String? pod;

  /// To set Background color
  final String? backgroundColor;

  /// To set status bar color for Android Only
  final String? statusbarColor;

  /// To set Toolbar Color
  final String? toolbarColor;

  /// To set Toolbar Text and icons color
  final String? toolbarTintColor;

  /// To enable disable the offline storage
  final bool? saveHistory;

  /// To enable disable the tokenize address in search result
  final bool? tokenizeAddress;
  final bool? userAddedLocationEnable;
  final double? zoom;
  final LatLng? location;

  //new
  final int? attributionHorizontalAlignment;
  final int? attributionVerticalAlignment;
  final int? logoSize;

  //ios
  final String? primaryTextColor;
  final String? tintColor;
  final String? tableCellSeparatorColor;
  final String? primaryTextHighlightColor;

  /// To enable bridge parameter in Autosuggest request
  final bool? bridge;
  final bool? hyperLocal;
  final int? minCharactersForSearch;

  PlaceOptions(
      {this.enableTextSearch,
      this.filter,
      this.hint,
      this.historyCount,
      this.limit,
      this.pod,
      this.saveHistory,
      this.backgroundColor,
      this.statusbarColor,
      this.toolbarColor,
      this.toolbarTintColor,
      this.tokenizeAddress,
      this.userAddedLocationEnable,
      this.zoom,
      this.location,

      //new
      this.attributionVerticalAlignment = PlaceOptions.GRAVITY_TOP,
      this.attributionHorizontalAlignment = PlaceOptions.GRAVITY_LEFT,
      this.logoSize = PlaceOptions.SIZE_MEDIUM,

      //ios
      this.primaryTextColor,
      this.tintColor,
      this.tableCellSeparatorColor,
      this.primaryTextHighlightColor,
      this.bridge,
      this.hyperLocal,
      this.minCharactersForSearch});

  Map<String, dynamic> toMap() {
    final Map<String, dynamic> optionsMap = <String, dynamic>{};

    void addIfNonNull(String fieldName, dynamic value) {
      if (value != null) {
        optionsMap[fieldName] = value;
      }
    }

    addIfNonNull('enableTextSearch', enableTextSearch);
    addIfNonNull('filter', filter);
    addIfNonNull('hint', hint);
    addIfNonNull('historyCount', historyCount);
    addIfNonNull('limit', limit);
    addIfNonNull('pod', pod);
    addIfNonNull('saveHistory', saveHistory);
    addIfNonNull('backgroundColor', backgroundColor);
    addIfNonNull('statusbarColor', statusbarColor);
    addIfNonNull('toolbarColor', toolbarColor);
    addIfNonNull('toolbarTintColor', toolbarTintColor);
    addIfNonNull('tokenizeAddress', tokenizeAddress);
    addIfNonNull('userAddedLocationEnable', userAddedLocationEnable);
    addIfNonNull('zoom', zoom);
    if (location != null) {
      addIfNonNull('location', location?.toJson());
    }

    //ios
    addIfNonNull('primaryTextColor', primaryTextColor);
    addIfNonNull('tintColor', tintColor);
    addIfNonNull('tableCellSeparatorColor', tableCellSeparatorColor);
    addIfNonNull('primaryTextHighlightColor', primaryTextHighlightColor);
    addIfNonNull(
        'attributionHorizontalAlignment', attributionHorizontalAlignment);
    addIfNonNull('attributionVerticalAlignment', attributionVerticalAlignment);
    addIfNonNull('logoSize', logoSize);

    addIfNonNull('bridge', bridge);
    addIfNonNull('hyperLocal', hyperLocal);
    addIfNonNull('minCharactersForSearch', minCharactersForSearch);

    return optionsMap;
  }
}
